==> haskell-hasql-transaction-1.0.1.1-189-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-KuJMSZesBWCJfBnbhIt6oT
key:                  hasql-transaction-1.0.1.1-KuJMSZesBWCJfBnbhIt6oT
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  408bf7995937c888c6635e3b1b6b85c7
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-KuJMSZesBWCJfBnbhIt6oT
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    bytestring-tree-builder-0.2.7.10-K8TspFfwCKEKbQROA8JFnw
    contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    contravariant-extras-0.3.5.3-LpchVnShsLR7WYk4qtOxKD
    hasql-1.5.0.4-AxOLagKDd24JNBZUns5aAZ mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-1.0.1.1-222-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-K2KazeYE3cFH5kLHzrW2Ig
key:                  hasql-transaction-1.0.1.1-K2KazeYE3cFH5kLHzrW2Ig
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  218208428813b00d5932fd96cd601bc0
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-K2KazeYE3cFH5kLHzrW2Ig
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    bytestring-tree-builder-0.2.7.10-BMLbljvKJoxGFo7ukAGMdY
    contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    contravariant-extras-0.3.5.4-2ZdosnG1W1YLci0at1WZWh
    hasql-1.5.0.4-GTFyrvK0wLiDzWMCYSMtQd mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
